@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2014 Henning Norén
+ * Copyright (C) 2006-2015 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,7 +36,7 @@
 
 #define BENCHINTERVAL 3 /** The interval to run the specific benchmarks */
 
-static bool finished = false;
+static volatile bool finished = false;
 
 /** interruptBench is used to stop the current benchmark */
 static void
@@ -121,7 +121,7 @@ md5_50_bench(void) {
   unsigned int nrprocessed = 0;
   clock_t startTime, endTime;
   int i;
-
+  
   buf = calloc(16, sizeof(uint8_t));
   md5_50_init(16);
   alarm(BENCHINTERVAL);
