@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2014 Henning Norén
+ * Copyright (C) 2006-2015 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -198,7 +198,7 @@ static p_str*
 parseHexString(const uint8_t *buf, const unsigned int len) {
   unsigned int i,j;
   p_str *ret;
- 
+
   ret = malloc(sizeof(p_str));
   ret->content = malloc(sizeof(uint8_t)*(len/2));
   ret->len = (len/2);
@@ -289,7 +289,7 @@ static p_str*
 parseRegularString(FILE *file) {
   unsigned int len, p;
   int ch;
-  p_str *ret;
+  p_str *ret = NULL;
   uint8_t buf[BUFFSIZE];
   bool skip = false;
 
@@ -312,7 +312,8 @@ parseRegularString(FILE *file) {
       ch = getc(file);
     }
     ungetc(ch, file);
-    ret = objStringToByte(buf, len);
+    if(len > 0)
+      ret = objStringToByte(buf, len);
   }
   else if(ch == '<') {
     len = 0;
@@ -325,10 +326,9 @@ parseRegularString(FILE *file) {
       ch = getc(file);
     }
     ungetc(ch,file);
-    ret = parseHexString(buf,len);
+    if((len > 1) && ((len%2) == 0))
+      ret = parseHexString(buf,len);
   }
-  else
-    ret = NULL;
 return ret;
 }
 
@@ -403,6 +403,9 @@ findTrailerDict(FILE *file, EncData *e) {
 	    */
 	    if(str)
 	      id = true;
+	    else
+	      id = false;
+
 	    ch = getc(file);
 	  }
 	  else
@@ -492,7 +495,7 @@ findTrailer(FILE *file, EncData *e) {
 		encrypt = true;
 	      }
 	    }
-	    else if(ch == 'I' && getc(file) == 'D') {
+	    else if(!id && ch == 'I' && getc(file) == 'D') {
 	      ch = parseWhiteSpace(file);
 	      while(ch != '[' && ch != EOF)
 		ch = getc(file);
@@ -502,13 +505,13 @@ findTrailer(FILE *file, EncData *e) {
 		  free(str->content);
 		free(str);
 	      }
-
+	      
 	      str = parseRegularString(file);
 	      /**
-	      pos_i = ftell(file);
-	      printf("found ID at pos %x\n", pos_i);
+		 pos_i = ftell(file);
+		 printf("found ID at pos %x\n", pos_i);
 	      */
-	      if(str)
+	      if(str) 
 		id = true;
 	      ch = getc(file);
 	    }
@@ -725,20 +728,20 @@ parseEncrypObject(FILE *file, EncData *e) {
   if(fr) {
     if (e->revision >= 5 && fu && fo) {
       if(o_len < 48) {
-	fprintf(stderr, "WARNING: O-String < 48 Bytes: %d\n", str->len);
+	fprintf(stderr, "WARNING: O-String < 48 Bytes: %d\n", o_len);
 	fo = false;
       }
       if(u_len < 48) {
-	fprintf(stderr, "WARNING: U-String < 48 Bytes: %d\n", str->len);
+	fprintf(stderr, "WARNING: U-String < 48 Bytes: %d\n", u_len);
 	fu = false;
       }
     }
     else {
       if(fu && fo) {
 	if(o_len != 32)
-	  fprintf(stderr, "WARNING: O-String != 32 Bytes: %d\n", str->len);
+	  fprintf(stderr, "WARNING: O-String != 32 Bytes: %d\n", o_len);
 	if(u_len != 32)
-	  fprintf(stderr, "WARNING: U-String != 32 Bytes: %d\n", str->len);
+	  fprintf(stderr, "WARNING: U-String != 32 Bytes: %d\n", u_len);
       }
       if (cf && aesv2) {
 	e->revision = 3;
@@ -747,7 +750,7 @@ parseEncrypObject(FILE *file, EncData *e) {
     }
   }
 
-  if(strcmp(e->s_handler,"Standard") != 0)
+  if(ff && strcmp(e->s_handler,"Standard") != 0)
     return true;
 
   return ff & fo && fp && fr && fu;
