@@ -27,8 +27,7 @@ rc4Decrypt(const uint8_t *key, const uint8_t *bs,
 	   const unsigned int len, uint8_t *out);
 
 bool
-rc4Match40b(const uint8_t *key, const uint8_t *bs,
-	    const unsigned int len, const uint8_t *match);
+rc4Match40b(const uint8_t *key, const uint8_t *bs, const uint8_t *match);
 
 bool
 setrc4DecryptMethod(const unsigned int length);
